@@ -121,10 +121,15 @@ class RoundcubeAutoLogin
 
         preg_match('|<input type="hidden" name="_token" value="([A-z0-9]*)">|', $response, $matches);
 
-        if($matches) {
+        if ($matches) {
             return $matches[1];
         }
         else {
+            //try it without the quotes
+            preg_match('|<input type=hidden name=_token value=([A-z0-9]*)>|', $response, $matches);
+            if ($matches) {
+                return $matches[1];
+            }
             return FALSE;
         }
     }
